Description Usage Arguments Value See Also
A utility that extracts the estimated penalty matrix from a
fitted object of class penfa.
1 |
x |
An object of class |
type |
Character denoting the type of penalization. Type equal to
|
which |
Character prompting the extraction of the penalty matrix
component corresponding to the specified model matrix. It is only valid
when |
A penalty matrix of class penfaPenMat. If multiple elements
are specified in the which argument, a list of penalty matrices (one
for each element, and each of class penfaPenMat) is returned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.