An S4 method showing information on the penalization process, including the employed penalty functions and the model matrices they affect. Additionally, it reports the optimal values of the tuning parameters and the tuning parameter selection strategy. If the automatic procedure was used, the output would also show the value of the influence factor, and the number of two-steps iterations.
# S4 method for penfaPenalty
show(object)An object of class penfaPenalty, found in the
Penalize slot from an object of penfa class.
An object reporting a short summary of the penalization process for
a fitted penfa model.