Description Slots See Also Examples
The penfaData class gives information on the data set
provided in input for analysis. This class is an adaptation of the
lavData class from the
lavaan package.
ngroupsInteger. The number of groups.
groupCharacter. The observed variables defining the groups.
group.labelCharacter. The group labels, that is, the values of the
group variable, if any.
std.ovLogical indicating whether the observed variables should be standardized.
nobsList of the effective number of observations in each group.
norigList of the original number of observations in each group.
ov.namesList of the observed variable names in each group.
ovList of details at the observed variable level.
case.idxList of the case (i.e., observation) indices in each group.
XList. Local copy of the input data set split into groups.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | data(ccdata)
syntax = 'help =~ h1 + h2 + h3 + h4 + h5 + h6 + h7 + 0*v1 + v2 + v3 + v4 + v5
voice =~ 0*h1 + h2 + h3 + h4 + h5 + h6 + h7 + v1 + v2 + v3 + v4 + v5'
alasso_fit <- penfa(## factor model
model = syntax,
data = ccdata,
std.lv = TRUE,
## penalization
pen.shrink = "alasso",
eta = list(shrink = c("lambda" = 0.01), diff = c("none" = 0)),
## automatic procedure
strategy = "auto")
alasso_fit@Data
str(alasso_fit@Data)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.