strategyCharacter. The strategy used for the selection of the tuning
parameter(s). If strategy = "auto", the optimal values of the tuning
parameters are determined via the automatic tuning parameter procedure; if
strategy = "fixed", a penalized factor model with the values of the
tuning parameters stored in the option eta is estimated.
penaltyList. A list of the user-specified penalty functions for
sparsity ("shrink") and parameter equivalence ("diff").
tuningList. A named list containing the optimal values of the tuning
parameter(s) if strategy = "auto" or the user-specified fixed
values of the tuning parameter(s) if strategy = "fixed". The list
has two components with names "shrink" and "diff", and refers to the tuning
parameters used for shrinkage and group equivalence, respectively. The
components of the list are, in turn, the named vectors specifying the type
of parameter matrices or vectors that were penalized.
pmatList. A named list containing the names of the parameter matrices
and vectors that were penalized for sparsity ("shrink") and/or group
equivalence ("diff").
pen.idxList. A named list with the indices of the parameters that were
penalized for sparsity ("shrink") and/or group equivalence ("diff").
Sh.infoList. A list of the penalization terms, vectors and matrices
evaluated at the optimal values of the tuning parameters. In particular,
its argument S.h returns the estimated penalty matrix. If the factor
model is penalized only through a shrinkage penalty (i.e.,
pen.shrink is not 'none'), and there is no penalization on
the differences (i.e., pen.diff = 'none'), then S.h is a
diagonal matrix whose elements precisely quantify the extent to which each
model parameter has been penalized.
extraList. A list possibly containing additional information on the
penalization process, such as the hyperparameter values for some penalty
functions (e.g., for the alasso, the value of the exponent and the adaptive
weights.)
automaticList. If strategy = "auto", it contains information on
the automatic multiple tuning parameter procedure, such as the optimal
values of the tuning parameters, the convergence status, the specified
value of the influence factor, the number of necessary iterations, and the
tolerance level.