Description Slots See Also Examples
The penfaSampleStats class provides information on the
sample moments of the factor analysis model. This
class is an adaptation of the lavSampleStats class from the
lavaan package.
varList of the variances of the observed variables in every group.
covList of the covariance matrices of the observed variables in every group.
meanList of the means of the observed variables in every group.
group.wList of group weights.
nobsList of the effective number of observations for every group.
ntotalInteger. Total number of observations across all groups.
ngroupsInteger. Number of groups.
icovList of the inverse matrices of the covariance matrices of the observed variables in every group.
cov.log.detList of the logarithms of the determinants of the covariance matrices of the observed variables for every group.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 | data(ccdata)
syntax = 'help =~ h1 + h2 + h3 + h4 + h5 + h6 + h7 + 0*v1 + v2 + v3 + v4 + v5
voice =~ 0*h1 + h2 + h3 + h4 + h5 + h6 + h7 + v1 + v2 + v3 + v4 + v5'
alasso_fit <- penfa(## factor model
model = syntax,
data = ccdata,
std.lv = TRUE,
## penalization
pen.shrink = "alasso",
eta = list(shrink = c("lambda" = 0.01), diff = c("none" = 0)),
## automatic procedure
strategy = "auto")
alasso_fit@SampleStats
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.